# DeploymentTargetResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**environment_ids** | **list[str]** |  | [optional] 
**roles** | **list[str]** |  | [optional] 
**tenanted_deployment_participation** | **str** |  | [optional] 
**tenant_ids** | **list[str]** |  | [optional] 
**tenant_tags** | **list[str]** |  | [optional] 
**space_id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**thumbprint** | **str** |  | [optional] 
**uri** | **str** |  | [optional] 
**is_disabled** | **bool** |  | [optional] 
**machine_policy_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**health_status** | **str** |  | [optional] 
**has_latest_calamari** | **bool** |  | [optional] 
**status_summary** | **str** |  | [optional] 
**is_in_process** | **bool** |  | [optional] 
**endpoint** | [**EndpointResource**](EndpointResource.md) |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


